import csv
import os
import re
import json
import requests
import pkg_resources
from datetime import datetime

DEFAULT_LOCATION_NAME = 'Johnson City'
DEFUALT_LOCATION_COORDS = ['36.3406', '-82.3804']
LOCATION_DATA = []

# LOCATION_DATA[0] = city, [1] = state name, [2] = state id
# [6] = latitude [7] = longitude
# Read in location data from uscitiesv1.5.csv.
def parse_location_data():
    # Join the package's path with the data path to access config.
    csvfile = pkg_resources.resource_filename(__name__, 'data/uscitiesv1.5.csv')
    with open(csvfile, 'r') as file_data:
        csv_reader = csv.reader(file_data)

        for row in csv_reader:
            LOCATION_DATA.append(row)

# Called on by send_forecast_in() or send_forecast_here() to create and return
# a formatted forecast message.
def create_forecast_message(weather_response):
    current_temp = str(weather_response['properties']['periods'][0]
                           ['temperature']) + ' degrees. '

    current_hour = datetime.now().hour

    # Correctly display forecast for 6am to 12pm.
    if (current_hour < 6) or (current_hour > 17):
        forecast_msg = (
            # Current day temp + forecast.
            '\n\n' + weather_response['properties']['periods'][0]['name']
            + ': ' + current_temp + (weather_response['properties']
                                    ['periods'][0]['detailedForecast'])
            # Next day temp + forecast.
            + '\n\n' + weather_response['properties']['periods'][1]['name']
            + ': ' + (weather_response['properties']['periods'][1]
                     ['detailedForecast'])

            # Next day temp + forecast.
           + '\n\n' + weather_response['properties']['periods'][3]['name']
            + ': ' + (weather_response['properties']['periods'][3]
                     ['detailedForecast'])

            # Next day temp + forecast.
            + '\n\n' + weather_response['properties']['periods'][5]['name']
            + ': ' + (weather_response['properties']['periods'][5]
                     ['detailedForecast'])

            # Next day temp + forecast.
            + '\n\n' + weather_response['properties']['periods'][7]['name']
            + ': ' + (weather_response['properties']['periods'][7]
                     ['detailedForecast'])

            # Next day temp + forecast.
            + '\n\n' + weather_response['properties']['periods'][9]['name']
            + ': ' + (weather_response['properties']['periods'][9]
                     ['detailedForecast'])
            )

    else:
        # Correctly display forecast for 6pm to 5am.
        forecast_msg = (
            # Current day temp + forecast.
            '\n\n' + weather_response['properties']['periods'][0]['name']
            + ': ' + current_temp + (weather_response['properties']
                                       ['periods'][0]['detailedForecast'])
            # Next day temp + forecast.
            + '\n\n' + weather_response['properties']['periods'][2]['name']
            + ': ' + (weather_response['properties']['periods'][2]
                     ['detailedForecast'])

            # Next day temp + forecast.
            + '\n\n' + weather_response['properties']['periods'][4]['name']
            + ': ' + (weather_response['properties']['periods'][4]
                     ['detailedForecast'])

            # Next day temp + forecast.
            + '\n\n' + weather_response['properties']['periods'][6]['name']
            + ': ' + (weather_response['properties']['periods'][6]
                     ['detailedForecast'])

            # Next day temp + forecast.
            + '\n\n' + weather_response['properties']['periods'][8]['name']
            + ': ' + (weather_response['properties']['periods'][8]
                     ['detailedForecast'])

            # Next day temp + forecast.
            + '\n\n' + weather_response['properties']['periods'][10]['name']
            + ': ' + (weather_response['properties']['periods'][10]
                     ['detailedForecast'])
            )

    return forecast_msg


# Create and return the current weather info for the default location.
def send_weather_here():
    weather_response = (requests.get('https://api.weather.gov/points/'
                     + DEFUALT_LOCATION_COORDS[0] + ','
                     + DEFUALT_LOCATION_COORDS[1] + '/forecast').json())

    temp_string = str(weather_response['properties']['periods'][0]
                                      ['temperature']) + ' degrees. '

    current_weather = (weather_response['properties']['periods'][0]['name']
                    + ': ' + temp_string + (weather_response['properties']
                                           ['periods'][0]['detailedForecast']))

    return 'Weather for ' + DEFAULT_LOCATION_NAME + ': ' + current_weather


# Create and return the current weather info for a location other than the
# default location.
def send_weather_in(message):
    # Default reply if the territory is not in LOCATION_DATA:
    weather_msg = 'Weather data could not be found for that location.'

    # Split string in 2 and store 2nd string as place name to search.
    msg_split = message.split('weather in ', 1)
    place = msg_split[1]

    row_found = False
    str_search = re.match('.*,.*', place)
    # '.*,.*' means 'city, state' or 'city, state initials' so both
    # of these will be searched for in the for-loop.
    if (str_search):
        split_str = place.split(',', 1)
        for row in LOCATION_DATA:
            if ((row[0] in split_str[0])
               and (row[2] in split_str[1])):
                city = row[0]
                row_found = True
                break
            elif ((row[0] in split_str[0])
                 and (row[3]in split_str[1])):
                row_found = True
                break

    # else, only the city was specified. If two of the same cities, it will
    # return weather of the first one it came accross in LOCATION_DATA.
    else:
         for row in LOCATION_DATA:
            if (row[0] == place):
                row_found = True
                break


    if (row_found):

        weather_response = (requests.get('https://api.weather.gov/points/'
                         + row[6] + ',' + row[7] + '/forecast').json())

        if not('status' in weather_response.keys()):
            current_weather = ((weather_response['properties']['periods'][0]
                                                ['name']) + ' '
                            + (weather_response['properties']['periods'][0]
                                               ['detailedForecast']))

            weather_msg = ('Weather for ' + row[0].capitalize() + ', '
                           + row[3].capitalize() + ': ' + current_weather)

    return weather_msg


# Create and return a 6-day weather forecast message for the default
# location.
def send_forecast_here():
    weather_response = (requests.get('https://api.weather.gov/points/'
                     + DEFUALT_LOCATION_COORDS[0]
                     + ',' + DEFUALT_LOCATION_COORDS[1] + '/forecast').json())

    current_weather = create_forecast_message(weather_response)

    return 'Weather for ' + DEFAULT_LOCATION_NAME + ': ' + current_weather


# Create and return a 6-day weather forecast message for a location other
# than the default location.
def send_forecast_in(message):
    # Default reply if the territory is not in LOCATION_DATA:
    weather_msg = 'Weather data could not be found for that location.'

    # Split string in 2 and store 2nd string as place name to search.
    msg_split = message.split('forecast in ', 1)
    place = msg_split[1]

    row_found = False
    str_search = re.match('.*,.*', place)
    # '.*,.*' means 'city, state' or 'city, state initials' so both
    # of these will be searched for in the for-loop.
    if (str_search and ',' in place):
        split_str = place.split(',', 1)
        for row in LOCATION_DATA:
            if ((row[0] in split_str[0]) # Try to match city, state initials.
               and (row[2] in split_str[1])):
                row_found = True
                break
            elif ((row[0] in split_str[0]) # Try to match city, state.
                 and (row[3] in split_str[1])):
                row_found = True
                break
    # else, only the city was specified. If two of the same cities, it will
    # return forecast of the first one it came accross in LOCATION_DATA.
    else:
         for row in LOCATION_DATA:
            if (row[0] == place):
                row_found = True
                break


    if (row_found):

        weather_response = (requests.get('https://api.weather.gov/points/'
                         + row[6] + ',' + row[7] + '/forecast').json())

        # When the response contains a 'status' this means an error occurred
        # (such as not having info about the coordinates specified),
        # therefore, we wouldn't be able to create a forecast message; code
        # would throw exception.
        if not ('status' in weather_response.keys()):
            current_weather = create_forecast_message(weather_response)
            weather_msg = ('Weather for ' + row[0].capitalize() + ', '
                           + row[3].capitalize() + ': ' + current_weather)

    return weather_msg


# Search strings about weather to determine whether to send
# default weather or weather in specified location.
def get_weather(msg):
    msg_text = msg.lower()

    reply = ''
    while True:
        str_search = re.search('tell.*weather in.*', msg_text)
        if (str_search):
            reply = send_weather_in(msg_text)
            break
        else:
            str_search = re.search('tell.*weather', msg_text)
            if (str_search):
                reply = send_weather_here()
                break

        str_search = re.search('what.*s.*weather in.*', msg_text)
        if (str_search):
            reply = send_weather_in(msg_text)
            break
        else:
            str_search = re.search('what.*s.*weather', msg_text)
            if (str_search):
                reply = send_weather_here()
                break

    return reply


# Search strings about forecast to determine whether to send
# default forecast or forecast in specified location.
def get_forecast(msg):
    msg_text = msg.lower()

    reply = ''
    while True:
        str_search = re.search('tell.*forecast in.*', msg_text)
        if (str_search):
            reply = send_forecast_in(msg_text)
            break
        else:
            str_search = re.search('tell.*forecast', msg_text)
            if (str_search):
                reply = send_forecast_here()
                break

        str_search = re.search('what.*s.*forecast in.*', msg_text)
        if (str_search):
            reply = send_forecast_in(msg_text)
            break
        else:
            str_search = re.search('what.*s.*forecast', msg_text)
            if (str_search):
                reply = send_forecast_here()
                break

    return reply



# reconfig_util.py
import re
import os
import pkg_resources

def main():
    config_data = []
    loop_input = True

    print('################ motioneyebot Configuration ################')
    print('\nThank you for using motioneyebot! Please note that this')
    print('\nprocess will reset your current motioneyebot configuration.')

    usr_input = input('\n     Press Enter to continue or \'q\' to quit. >> ')

    if (usr_input.lower() == 'q'):
        exit(0)

    while loop_input:

        print('\n')
        usr_input = input('1) Enter the your GroupMe access token >> ')
        config_data.append(usr_input)

        usr_input = input('2) Now enter your GroupMe bot ID >> ')
        config_data.append(usr_input)

        usr_input = input('3) Now enter your GroupMe group ID >> ')
        config_data.append(usr_input)

        usr_input = input('4) Enter the path to your server\'s index ' +
                            'page >> ')
        config_data.append(usr_input)

        usr_input = input('5) Enter the IP address of your MotionEye ' +
                            'camera >> ')
        config_data.append(usr_input)

        usr_input = input('6) Enter the public IP address of this device >> ')
        config_data.append(usr_input)

        usr_input = input('*Optional* Enter the URL to your camera ' +
                            'uploads >> ')
        if (len(usr_input) == 0):
                usr_input = '-' # Add space so config_data appends something.

        config_data.append(usr_input)

        usr_input = input('*Optional* Enter the name for your Bot (only' +
                        '\ndisplays in this program) >> ')
        if (len(usr_input) == 0):
                usr_input = 'Pops' # Add space so config_data appends something.

        config_data.append(usr_input)

        usr_input = input('*Optional* Enter the name for your Group (only' +
                        '\ndisplays in this program) >> ')
        if (len(usr_input) == 0):
                usr_input = 'motioneye Group' # Add space so config_data appends something.

        config_data.append(usr_input)

        missing_data = False
        for i in range(6):
            if (len(config_data[i]) == 0):
                # tell user first line left blank
                print('\nYou left one or more lines blank starting with' +
                    '\nline ' + str(i + 1) + '\n')
                # clear contents of array if user forgot to enter line
                # don't let code crash if user entered nothing
                if (len(config_data) > 0):
                    del(config_data[:])
                missing_data = True
                break

        if not (missing_data):
            loop_input = False

    configfile = pkg_resources.resource_filename(__name__, 'data/config.txt')
    with open(configfile, 'w') as f:

        f.write('ACCESS_TOKEN = \'' + config_data[0] +
                    '\'     # GROUPME ACCESS TOKEN\n')

        f.write('BOT_ID = \'' + config_data[1] +
                    '\'         # GROUPME BOT ID\n')

        f.write('GROUP_ID = \'' + config_data[2] +
                    '\'       # GROUPME GROUP ID\n')

        f.write('INDEX_LOCATION = \'' + config_data[3] +
                    '\'# PATH TO SERVER INDEX PAGE\n')

        f.write('MOTIONEYE_IP = \'' + config_data[4] +
                    '\'   # IP ADDRESS OF MOTIONEYE CAM\n')

        f.write('PUBLIC_IP = \'' + config_data[5] +
                    '\'      # PUBLIC IP ADDRESS OF THIS DEVICE\n')

        f.write('UPLOADS_URL = \'' + config_data[6] +
                    '\'    # DROPBOX OR DRIVE URL TO UPLOADS\n')

        f.write('BOT_NAME = \'' + config_data[7] +
                    '\'       # GROUPME BOT NAME (ARBITRARY)\n')

        f.write('GROUP_NAME = \'' + config_data[8] +
                    '\'     # GROUPME GROUP NAME (ARBITRARY)')
main()



import re
import os
import pkg_resources

def main():
    config_data = []
    loop_input = True
    missing_data = False

    # Initialize all data necessary to run the program from config.

    # Join the package's path with the data path to access config.
    configfile = pkg_resources.resource_filename(__name__, 'data/config.txt')
    with open(configfile, 'r') as f:
        for i, line in enumerate(f):
            # Parse user's string and store in config_data[]:
            if ('=' in line):
                split_str = line.split('=', 1)
                var = split_str[1].replace("'", '')
                config_data.append(re.sub(r'#.*', '', var).strip())

                # Close program if all necessary fields are entered:
                if (len(config_data[i]) == 0):
                    missing_data = True

    # If file is completely blank.
    if (len(config_data) == 0):
        missing_data = True

    if (missing_data):

        del(config_data[:])
        print('################ motioneyebot Configuration ################')
        print('\nThank you for using motioneyebot! If you haven\'t already,')
        print('\ntake the time to read README.rst before continuing with setup.')
        usr_input = input('\n     Press Enter to continue or \'q\' to quit. >> ')

        if (usr_input.lower() == 'q'):
            exit(0)

        while loop_input:

            print('\n')
            usr_input = input('1) Enter the your GroupMe access token >> ')
            config_data.append(usr_input)

            usr_input = input('2) Now enter your GroupMe bot ID >> ')
            config_data.append(usr_input)

            usr_input = input('3) Now enter your GroupMe group ID >> ')
            config_data.append(usr_input)

            usr_input = input('4) Enter the path to your server\'s index ' +
                                'page >> ')
            config_data.append(usr_input)

            usr_input = input('5) Enter the IP address of your MotionEye ' +
                                'camera >> ')
            config_data.append(usr_input)

            usr_input = input('6) Enter the public IP address of this device >> ')
            config_data.append(usr_input)

            usr_input = input('*Optional* Enter the URL to your camera ' +
                                'uploads >> ')
            if (len(usr_input) == 0):
                    usr_input = '-' # Add space so config_data appends something.

            config_data.append(usr_input)

            usr_input = input('*Optional* Enter the name for your Bot (only' +
                            '\ndisplays in this program) >> ')
            if (len(usr_input) == 0):
                    usr_input = 'Pops' # Add space so config_data appends something.

            config_data.append(usr_input)

            usr_input = input('*Optional* Enter the name for your Group (only' +
                            '\ndisplays in this program) >> ')
            if (len(usr_input) == 0):
                    usr_input = 'motioneye Group' # Add space so config_data appends something.

            config_data.append(usr_input)

            missing_data = False
            for i in range(6):
                if (len(config_data[i]) == 0):
                    # tell user first line left blank
                    print('\nYou left one or more lines blank starting with' +
                        '\nline ' + str(i + 1) + '\n')
                    # clear contents of array if user forgot to enter line
                    # don't let code crash if user entered nothing
                    if (len(config_data) > 0):
                        del(config_data[:])
                    missing_data = True
                    break

            if not (missing_data):
                loop_input = False

        with open(configfile, 'w') as f:

            f.write('ACCESS_TOKEN = \'' + config_data[0] +
                        '\'     # GROUPME ACCESS TOKEN\n')

            f.write('BOT_ID = \'' + config_data[1] +
                        '\'         # GROUPME BOT ID\n')

            f.write('GROUP_ID = \'' + config_data[2] +
                        '\'       # GROUPME GROUP ID\n')

            f.write('INDEX_LOCATION = \'' + config_data[3] +
                        '\'# PATH TO SERVER INDEX PAGE\n')

            f.write('MOTIONEYE_IP = \'' + config_data[4] +
                        '\'   # IP ADDRESS OF MOTIONEYE CAM\n')

            f.write('PUBLIC_IP = \'' + config_data[5] +
                        '\'      # PUBLIC IP ADDRESS OF THIS DEVICE\n')

            f.write('UPLOADS_URL = \'' + config_data[6] +
                        '\'    # DROPBOX OR DRIVE URL TO UPLOADS\n')

            f.write('BOT_NAME = \'' + config_data[7] +
                        '\'       # GROUPME BOT NAME (ARBITRARY)\n')

            f.write('GROUP_NAME = \'' + config_data[8] +
                        '\'     # GROUPME GROUP NAME (ARBITRARY)')
main()



#! /usr/bin/env python

from setuptools import setup, find_packages
from setuptools.command.install import install

with open("README.rst", "r") as readme:
    long_desc = readme.read()

setup(
    name='motioneyebot',
    version='0.1.2',
    license='MIT',
    author='Ryan Haas',
    author_email='haasrr@etsu.edu',
    description='Use a GroupMe bot to post images from a MotionEyeOS camera, chat with members, and provide US weather reports in your GroupMe group.',
    long_description=long_desc,
    long_description_content_type='text/x-rst',
    url='https://github.com/haasr/pops-bot-motioneye',
    packages=find_packages(),
    classifiers=[
        'Intended Audience :: Other Audience',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3 :: Only'
    ],
    entry_points={
        'console_scripts': [
            'motioneyebot=motioneyebot.app:main',
            'motioneyeconfig=motioneyebot.reconfig_util:main'
        ],
    },
    package_data={
        'motioneyebot': ['data/config.txt',
                        'data/csv_file_license.html',
                        'data/worldcities.csv']
    },
    include_package_data=True,
    zip_safe=False,
    python_requires='>=3.5',
    install_requires=['requests>=2.22.0']
)



# app.py

import os
import re
import time
import random
import requests
import pkg_resources
from multiprocessing import Process
from motioneyebot import config_util
from motioneyebot import pops_calls
from motioneyebot import weather_util

config_constants = []

# Join the package's path with the data path to access config.
configfile = pkg_resources.resource_filename(__name__, 'data/config.txt')
with open(configfile, 'r') as f:
    for i, line in enumerate(f):
        # Parse user's string and store in config_constants[]:
        if ('=' in line):
            split_str = line.split('=', 1)
            var = split_str[1].replace("'", '')
            config_constants.append(re.sub(r'#.*', '', var).strip())

ACCESS_TOKEN = config_constants[0]
BOT_ID = config_constants[1]
GROUP_ID = config_constants[2]
INDEX_LOCATION = config_constants[3]
MOTIONEYE_IP = config_constants[4]
PUBLIC_IP = config_constants[5]
UPLOADS_URL = config_constants[6]
BOT_NAME = config_constants[7]
GROUP_NAME = config_constants[8]

POST_URL = 'https://api.groupme.com/v3/bots/post'

request_params = { 'token': ACCESS_TOKEN }


def send_reply(reply, message):
    post_params = { 'bot_id': BOT_ID, 'text': reply }
    req = requests.post(POST_URL, params = post_params)
    request_params['since_id'] = message['id']

    print(message['text'] + '\n')
    print('Sent reply: ' + reply)
    print(req) # Print http response.


def send_snap_reply(message):

    # Location of web server's index page and dir where images are
    # stored so they can be accessed by url
    # 'public_ip_address/image_name.jpeg'
    # for example, '12.345.67.89/0002021312312312.jpeg'
    test = os.listdir(INDEX_LOCATION)

    i = 0
    for item in test:
        i += 1

    if (i > 49): # Clear out folder every 50 images.
        for item in test:
            # Remove all old jpegs from previous downloads.
            if (item.endswith('.jpeg')):
                os.remove(os.path.join(INDEX_LOCATION, item))

    # Goal here is basically to create an image name that will never be
    # used again. Workaround for groupme api caching first image from
    # url and never sending new image even after content in
    # 'current.jpeg', for example, had changed.

    filename = (str(random.randint(0, 90000000))
             + str(random.randint(0, 90000000)) + '.jpeg')

    with open('/var/www/html/' + filename, 'wb') as jpeg:
        jpeg.write(requests.get('http://' + MOTIONEYE_IP
                            + '/picture/1/current/').content)

    post_params = { 'bot_id': BOT_ID, 'text': '' }
    post_data = {'text': 'current.jpeg', 'picture_url':
    ('http://' + PUBLIC_IP + '/' + filename)}
    req = requests.post(POST_URL, params = post_params, data = post_data)
    request_params['since_id'] = message['id']

    print(message['text'] + '\n')
    print('Sent most recent image snap')
    print(req) # Print http response.


def main():
    # Parse in all the location data from file:
    weather_util.parse_location_data()

    while True:
        try:
            response = requests.get('https://api.groupme.com/v3/groups/'
                     + GROUP_ID + '/messages', params = request_params)

            if (response.status_code == 200):
                response_messages = response.json()['response']['messages']

                print('\n####################'
                     + '\n# Bot: ' + BOT_NAME
                     + '\n# Group: ' + GROUP_NAME
                     + '\n# Status: Listening'
                     + '\n ###################')

                # Iterate through each message, checking its text
                for message in response_messages:
                    if not (message['text'] == None):
                        # Test for Weather query first
                        # Forecast searches before weather because ppl may
                        # say "Whats the weather forecast":
                        str_search = re.search('what.*s.*forecast',
                        message['text'].lower())
                        if (str_search):
                            reply = weather_util.get_forecast(message['text'])
                            send_reply(reply, message)
                            break

                        str_search = re.search('tell.*forecast',
                        message['text'].lower())
                        if (str_search):
                            reply = weather_util.get_forecast(message['text'])
                            send_reply(reply, message)
                            break

                        str_search = re.search('what.*s.*weather',
                        message['text'].lower())
                        if (str_search):
                            reply = weather_util.get_weather(message['text'])
                            send_reply(reply, message)
                            break

                        str_search = re.search('tell.*weather',
                        message['text'].lower())
                        if (str_search):
                            reply = weather_util.get_weather(message['text'])
                            send_reply(reply, message)
                            break

                        # If someone tags Pops (and not to ask weather),
                        # pops_calls handles the reply:
                        if ('@pops' in message['text'].lower()):
                            reply = pops_calls.get_reply(message)
                            send_reply(reply, message)
                            break

                        # Key words to get info from MotionEye camera;
                        # popcam_calls handles these.

                        # I have an IFTTT webhook which when called by
                        # MotionEye, posts 'ALERT!!...' when motion is
                        # detected. Then my bot knows to post a current
                        # snapshot:
                        elif (('ALERT!!' in message['text'])
                             or (message['text'] == 'SNAP')):

                            attempt_send = Process(target =
                            send_snap_reply(message))

                            attempt_send.start()
                            # Max time function can run is 45 secs.
                            attempt_send.join(timeout = 45)
                            # Terminate if still running after 45.
                            attempt_send.terminate()
                            break

                        elif (message['text'] == 'STREAM'):
                            send_reply(MOTIONEYE_IP, message)
                            break

                        elif (message['text'] == 'UPLOADS'):
                            # A dash is stored if no URL was given.
                            if not (UPLOADS_URL == '-'):
                                send_reply(UPLOADS_URL, message)
                            break

        except requests.exceptions.ConnectionError as e:
            print('No connection')
            print(e)

        except requests.exceptions.Timeout as e:
            print('Connection timed out')
            print(e)

        except requests.exceptions.RequestException as e:
            print('A request error ocurred')
            print(e)

        except:
            print('An error occurred')

        time.sleep(5)
main()




# pops_calls.py

import re
import random
from motioneyebot import weather_util

JOKES = [
    ' you were born...',
    '\nQ: What do you call a fish without an eye?\n\nA: A fsh.',
    ' I went to a restaurant on the moon the other day, the food' +
    ' was great but there was just no atmosphere',
    ' two guys walked into a bar, I just walked underneath.',
    ' the 3 unwritten rules of life:\n   1:\n   2:\n   3:',
    ' what do you and a bungalow have in common?\nNothing upstairs!',
    ' my food lasts longer than your relationships',
    ' I\'m an acquired taste. if you don\'t like me, acquire some taste.',
    ' If I had a face like yours, I\'d sue my parents',
    ' I called the Complaint Department and nobody answered. Now I have' +
    ' something else to complain about!'
]

PROVERBS = [
    'The too-lazy do a few things poorly; the too-busy do many things' +
    ' poorly.',
    'If you store food in your fridge, it may go bad. If you store food in' +
    ' your belly, you don\'t need a fridge.',
    'The faster one eats, the better the food tastes.',
    'Rome wasn\'t built in a day, but that\'s only because I wasn\'t there.',
    'When you are lacking in motivation, you are lacking in food.',
    'Better is the enemy of good and I am the enemy of squirrels!',
    'What is the meaning of life? I ate it while you were contemplating.',
    'Once you exceed your life limit, you cannot upgrade your plan.'
    'Life is noodles. Noodles is life.'
    'Nothing is in control and there\'s nothing you can do about it.',
    'There are 2 types of people: those who can interpret incomplete data' +
    ' sets.',
    'Someone told me the secret to happiness is to be grateful. ' +
    'I replied \"Thanks for nothing!\"'
]

BUSINESS_INFO = [
    'I am the CEO of the popcorn company, Pop Secret. ' +
    'I also own several exporting companies in China, Japan, and...well ' +
    'pretty much everywhere and definitely don\'t control all major world ' +
    'banks, monetary funds or the oil cartel...I am a busy chicken but I ' +
    'always have time for food.',

    'I eat food, I do that a lot. I also manage my businesses, keep the ' +
    'squirrells out of my terriory, I\'m getting into Real Estate, I ' +
    'tried to get into gardening but I always ate my plants before they ' +
    'grew up. I scuba dive, ski, play the harp, study abroad, etc, etc. A' +
    'better question is, what don\'t I do?',

    ' business is as usual I suppose, another day closer to world' +
    ' domina..fdsjl I mean, another day closer to world peace! HEEhehe'
]

MEANING_OF_LIFE = [
    'food.',
    'The answer is obvious.\n FOOD is the meaning of life!'
]

WHATS_UP = [
    ' munchin the foods',
    ' not watchin you, hehe',
    ' Sky diving.',
    ' why don\'t you tell me? You\'re the one spying on me with a camera!!',
    ' rocky mountain climbing.',
    ' exporting luxury cars!',
    ' developing Skynet!!',
    ' travelling abroad, what are you doing?'
]

MOOD = [
    'Hungry',
    'Doing well. How are you?',
    'A little bit angry rn...These pesky squirrels will pay!!!',
    'Tired. just got back from a business trip in China.'
]

DAY = [
    ' my day has been ok so far, found some juicy bugs while in yard today',
    ' so-so. Achieving world domination err um,...world peace is a difficult' +
    ' task.',
    ' my day would be better if your brought me a cookie!!',
    ' made a good business deal today and my stocks are up! GOOd day.' +
    ' More importantly i got a yummy worm today!',
    ' ok but im tired of this weather. You feelin me? '
]

LOCATION = [
    ' I\'m in Zanzibar, an archipelago off of mainland Tanzania. I\'m' +
    ' visiting a local spice farm to test some spices that I\'m considering' +
    ' exporting to North America. Wbu?',

    ' I\'m watching a production of L\'Orfeo at the Teatro Alla Scalla in' +
    ' Milan. I\'m a better opera singer than these amateurs.',

    ' I\'m meeting the FC Barcelona team for soccer practice in Camp Nou,' +
    ' rn. How about you?',

    ' I\'m spelunking rn in Wind Cave Nat. Park. Where are you?',

    ' I\'m meeting to strike a deal with some eCommerce execs in Dubai. They' +
    ' think they have the upper hand, but they\'ve never negotiated with the' +
    ' Pops!',

    ' I\'m visiting the chicken farm at Biltmore to see some old friends.',

    ' checking out some real estate I\'m thinking about purchasing near' +
    ' Newcastle\, Ireland. The Popsinator needs a new golf course!!' +
    ' Where r u?',

    ' skiing in Ontario rn. Too cold up here!'
]

WEATHER = [
    'Currently freeze your beak off weather!! ',
    'Sweater weather ',
    'Temperate. Just the way Pops likes it ',
    'POPS-sicle weather ',
    'I\'m trying not to become a rotisserie '
]

SHOWS = [
    ' Seinfeld...NO SOUP FOR YOU!!',
    ' Shark Tank. One of my personal favs',
    ' Stranger Things. On the third season. NOoooo!! The Mind Flayer knows!!',
    ' Seinfeld. BIG SALAD',
    ' Inception. A dream inside a dream inside a dream...sounds like my life' +
    ' haha',
    ' A brief history of time -- about structure, origin and development' +
    ' of universe',
    ' into the universe with Stephen Hawking. talking about deep space gamma' +
    ' bursts rn'
]

BACKSTORY = 'I was born and raised in the Australian Out-bock where I' +\
    ' wrangled snakes and ran a Kangaroo farm. I was also studying' +\
    ' bioengineering at the University of Melbourne. One day while I was in' +\
    ' the lab, munching my fav snack --popcorn-- and working on a more' +\
    ' resilient strain of corn, it hit me! I could make better popcorn!!' +\
    ' So that\'s what I did! I started selling the kernels locally and' +\
    ' eventually caught the attention of the company, Pops Secret. They' +\
    ' bought my kernel research for a paultry $1.5 million but hired me' +\
    ' to work for them in America. I invested the money into several' +\
    ' hedge funds and Bitcoin and made my first billion. The rest is' +\
    ' history...'

WHAT_REPLIES = [
    'idk. Just sayin',
    'You heard me!',
    'What? We seem to be breaking up *crackle* *crackle*...bad connection',
    'I could ask you the same thing.'
]

WHY_REPLIES = [
    'Why not?',
    'Why? Why not??',
    'Because I said so, hahaha!',
    'Because food.'
]

YES_OR_NO = [
    'Yes ',
    'Definitely ',
    'No ',
    'Nope! ',
    'Probably ',
    'Probably not ',
    'What do you think '
]

FILLER_PHRASES = [
    'Ooh! foodds..djfs kdsak',
    'idk',
    'OOoh i Found f00d!! O>',
    'hmmm. No comment.',
    'jjkkkkkkkkkkkkkkkkkkjjsdfsrgss',
    'oOOOOOoh foooodS!!dsaf',
    'Sorry, I just keep thinking about PEanuT butter. PEnaut ButteR@!#',
    'Were you saying something?',
    'What were you saying? I couldn\'t read your comment over my popcorn' +
    ' munching!!',
    'You will never know the Pop\'s secret!!',
    'oii. The Pops does not understand.',
    'Im trying to focus on this conversation but I\'m watching ' +
    'a good show rn',
    'You might have to say that a different way.',
    'Gzzzzhgahhhh!'
]


def get_reply(msg):

    while True:
        msg_text = msg['text'].lower()

        # search all non-regex strings first
        if ('meaning of life' in msg_text):
            reply = MEANING_OF_LIFE[random.randint(0,
                                   (len(MEANING_OF_LIFE) - 1))]
            break

        elif ('how are you' in msg_text):
            reply = MOOD[random.randint(0, (len(MOOD) - 1))]
            break

        elif ('you from' in msg_text):
            reply = 'From the wild Out-bock mate!!'
            break

        elif ('where are you' in msg_text):
            reply = '@' + msg['name'] + LOCATION[random.randint(0,
                                                (len(LOCATION) - 1))]
            break

        elif ('about your business' in msg_text):
            reply = BUSINESS_INFO[0]
            break

        elif ('sup' in msg_text):
            reply = '@' + msg['name'] + WHATS_UP[random.randint(0,
                                                (len(WHATS_UP) - 1))]
            break

        elif ('were you born' in msg_text):
            reply = 'Don\'t you know that...I\'ve always been here?'
            break

        elif ('your story' in msg_text) or ('your backstory' in msg_text):
            reply = BACKSTORY
            break

        elif ('what?' in msg_text):
            reply = WHAT_REPLIES[random.randint(0, (len(WHAT_REPLIES) - 1))]
            break

        elif ('why?' in msg_text):
            reply = WHY_REPLIES[random.randint(0, (len(WHY_REPLIES) - 1))]
            break

        elif ('no thanks' in msg_text):
            reply = 'Fine @' + msg['name']
            break

        elif ('thanks' in msg_text):
            reply = '@' + msg['name'] + ' you\'re welcome'
            break

        elif (('yes' in msg_text) or ('good point' in msg_text) or
             ('true' in msg_text)):
            reply = 'Indeed ' + '@' + msg['name']
            break

        elif (('no' in msg_text) or ('nope' in msg_text) or
             ('wrong' in msg_text)):
            reply = 'Ok then ' + '@' + msg['name']
            break

        elif ('favorite color' in msg_text):
            reply = 'Clear.'
            break

        elif ('your favorite' in msg_text):
            reply = 'Needless to say, I\'m my favorite!'
            break

        elif (('should' in msg_text) or ('am i' in msg_text) or
             ('are we' in msg_text)):
            reply = YES_OR_NO[random.randint(0,
                             (len(YES_OR_NO) - 1))] + '@' + msg['name']
            break

        elif (('wise' in msg_text) or ('wisdom' in msg_text)):
            reply = PROVERBS[random.randint(0, (len(PROVERBS) - 1))]
            break

        elif ('i think' in msg_text):
            reply = '@' + msg['name'] + ', you\'re certainly entitled to' +\
                                        ' that opinion.'
            break

        elif ('bot' in msg_text):
            reply = 'You will never know the Pop\'s Secret!!'
            break

        # Save regex searches for last (slower)
        str_search = re.search('.*hello.*@pops', msg_text)
        if (str_search):
            reply = 'Hello ' + '@' + msg['name']
            break

        str_search = re.search('.*what.*s up', msg_text)
        if (str_search):
            reply = '@' + msg['name'] + WHATS_UP[random.randint(0,
                                                (len(WHATS_UP) - 1))]
            break

        str_search = re.search('tell.*joke', msg_text)
        if (str_search):
            reply = '@' + msg['name'] + JOKES[random.randint(0,
                                             (len(JOKES) - 1))]
            break

        str_search = re.search('tell.*proverb', msg_text)
        if (str_search):
            reply = PROVERBS[random.randint(0, (len(PROVERBS) - 1))]
            break

        str_search = re.search('tell.*truth', msg_text)
        if (str_search):
            reply = 'You can\'t handle the truth!!'
            break

        str_search = re.search('your favorite.*activity', msg_text)
        if (str_search):
            reply = MEANING_OF_LIFE[0]
            break

        str_search = re.search('what.*you watch.*', msg_text)
        if (str_search):
            reply = '@' + msg['name'] + SHOWS[random.randint(0,
                                             (len(SHOWS) - 1))]
            break

        str_search = re.search('how.*your day', msg_text)
        if (str_search):
            reply = '@' + msg['name'] + DAY[random.randint(0,
                                           (len(MOOD) - 1))]
            break

        str_search = re.search('.*how.*s.*business', msg_text)
        if (str_search):
            reply = '@' + msg['name'] + BUSINESS_INFO[2]
            break

        str_search = re.search('.*what.*you doing.*', msg_text)
        if (str_search):
            reply = '@' + msg['name'] + WHATS_UP[random.randint(0,
                                                (len(WHATS_UP) - 1))]
            break

        # needed this after question, 'what are you doing?'
        elif ('are you' in msg_text):
            reply = YES_OR_NO[random.randint(0, (len(YES_OR_NO) - 1))]
            break

        str_search = re.search('.*what.*you do', msg_text)
        if (str_search):
            reply = BUSINESS_INFO[1]
            break

        str_search = re.search('how.*s.*weather', msg_text)
        if (str_search):
            temp = weather_util.get_default_temp()

            if (temp < 33):
                reply = WEATHER[0] + '@' + msg['name']
            elif (temp < 50):
                reply = WEATHER[1] + '@' + msg['name']
            elif (temp < 76):
                reply = WEATHER[2] + '@' + msg['name']
            elif (temp < 86):
                reply = WEATHER[3] + '@' + msg['name']
            else:
                reply = WEATHER[4] + '@' + msg['name']

            break

        if ('?' in msg_text):
            reply = YES_OR_NO[random.randint(0, (len(YES_OR_NO) - 1))] +\
                 '@' + msg['name']
            break

        reply = FILLER_PHRASES[random.randint(0, (len(FILLER_PHRASES) - 1))]
        break

    return reply

